/*----------------------------------------------------------------------------*\
Application
	computeTorque

Description
	computes the pressure torque on a given surface

\*---------------------------------------------------------------------------*/

// Main program:

#include "fvCFD.H"

void computeTorq(word patchName, fvMesh& mesh, volScalarField& p);

int main(int argc, char *argv[])
{

#   include "setRootCase.H"

#   include "createTime.H"
#   include "createMesh.H"
#   include "createFields.H"
	
	computeTorq("rotor", mesh, p);
	
	const label buff = findMax(p);
	Info << "label: " << buff << " pMax: " << p[buff] << " point: " << mesh.C()[buff] << endl;


	
}

void computeTorq(word patchName, fvMesh& mesh, volScalarField& p)
{

	// get the label for the requested patch
 	label patchID = mesh.boundaryMesh().findPatchID(patchName);
	
	if (-1 == patchID)
	{
		Info << "no patch named "+patchName << endl <<"Available patches:" << endl;
		error err("Error!\n");

		//access boundary elements
		const fvPatchList& patches = mesh.boundary();
		
		//loop over boundaries
		forAll(patches, patchI)
		{ 	
			Info << patches[patchI].name() << endl;
		}
		
		err.exit();
	}
	
	const fvPatch& cPatch = mesh.boundary()[patchID];
	
	vector torque(0,0,0);
	const vector r0(0.48,0,0);
	const scalar omega = 104.72; //[rad/s] - 1000 rpm
	
/*	forAll(cPatch,faceI)
	{
		scalar pabs = p.boundaryField()[patchID][faceI]+101325;
		vector Area = cPatch.Sf()[faceI];
		vector r = cPatch.Cf()[faceI]-r0;
		vector force = pabs*Area;
		torque = torque+(r^force);
	}
*/	
	torque = sum((cPatch.Cf()-r0)^((p.boundaryField()[patchID]+101325)*cPatch.Sf()));
	Info << "torque(" << patchName << "): " << torque << " power: " << torque.x()*omega << "[W]" << endl;
}

